@@ -37,7 +37,7 @@ blk_dev_struct()
 		}
 	} else {
 		while (args[optind]) {
-			addr = getaddr(args[optind]);
+			addr = getvalue(args[optind]);
 			if (addr < MAX_BLKDEV) {
 				print_blk_dev_struct(blk_dev_addr, (int)addr);
 			} else {
@@ -61,7 +61,7 @@ request_queue()
 		THROW(usage);
 	}
 	while (args[optind]) {
-		(void) print_request(getaddr(args[optind]), 0);
+		(void) print_request(getvalue(args[optind]), 0);
 		optind++;
 	}
 	return 0;
