@@ -262,6 +262,10 @@ print_inode(addr, full)
 		else
 			mprintf("\n");
 		mprintf("\tsb:        " FPTR "  (super_block)\n", inode.i_sb);
+#if 0
+		mprintf("\twait:       " FPTR "  (wait_queue_head)\n",
+			inode.i_wait);
+#endif
 		mprintf("\tflock:     " FPTR "  (file_lock)\n", inode.i_flock);
 		if (inode.i_pipe)
 		mprintf("\tpipe:      " FPTR "\n", inode.i_pipe);
@@ -639,8 +643,13 @@ print_file_lock(addr, full, chain)
 			mprintf(SPTR " " SPTR "\n", "-", "-");
 		} else {
 			mprintf(FPTR " " FPTR "\n",
-				fl.fl_block.next, fl.fl_block.prev);
+				(addr_t)fl.fl_block.next - OFFSET(struct file_lock, fl_block),
+				(addr_t)fl.fl_block.prev - OFFSET(struct file_lock, fl_block));
 		}
+#if 1
+		mprintf("  wait:       " FPTR "  (wait_queue_head)\n",
+			addr + OFFSET(struct file_lock, fl_wait));
+#else
 		mprintf("  wait:       ");
 		if ((addr_t)fl.fl_wait.task_list.next == addr + OFFSET(struct file_lock, fl_wait.task_list)) {
 			mprintf(SPTR " " SPTR "\n", "-", "-");
@@ -649,6 +658,7 @@ print_file_lock(addr, full, chain)
 				fl.fl_wait.task_list.next,
 				fl.fl_wait.task_list.prev);
 		}
+#endif
 		mprintf("  not/ins/rem:" FPTR " " FPTR " " FPTR "\n",
 			fl.fl_notify, fl.fl_insert, fl.fl_remove);
 		mprintf("  fasync:     " FPTR "\n", fl.fl_fasync);
