@@ -234,7 +234,22 @@ print_task(addr, full)
 #endif /*ARCH_i386*/
 #if defined(ARCH_ia64)
 	mprintf("\tksp:%lx  flags:%lx\n", ts.thread.ksp, ts.thread.flags);
-	mprintf("\tmap_base:%lx  task_size:%lx\n", ts.thread.map_base, ts.thread.task_size);
+	mprintf("\tmap_base:%lx  task_size:%lx\n",
+		ts.thread.map_base, ts.thread.task_size);
+	if (full >= 2) {
+		struct switch_stack sw;
+		memread((addr_t)ts.thread.ksp + 16, sizeof(sw), &sw,
+			"switch_stack");
+		mprintf("\tb0:%lx    b1:%lx\n", sw.b0, sw.b1);
+		mprintf("\tpfs:%lx   (rrb.pr:%d, rrb.fr:%d, rrb.gr:%d, sor:%d, sol:%d, sof:%d)\n",
+			sw.ar_pfs, (int)(sw.ar_pfs>>32),
+			(int)(sw.ar_pfs>>25) & 127,
+			(int)(sw.ar_pfs>>18) & 127,
+			(int)(sw.ar_pfs>>14) & 15,
+			(int)(sw.ar_pfs>>7) & 127,
+			(int)sw.ar_pfs & 127);
+		mprintf("\tbspstore:%lx pr:%lx\n", sw.ar_bspstore);
+	}
 #endif /*ARCH_ia64*/
 #if defined(ARCH_ppc) || defined(ARCH_ppc64)
 	mprintf("\tksp:%lx\n", ts.thread.ksp);
@@ -269,17 +284,26 @@ getinfo_fromtask(addr, ip, sp, stack)
 	if (sp)
 		*sp = tsk.thread.esp;
 #else
-#if defined(ARCH_ia64) || defined(ARCH_ppc) || defined(ARCH_ppc64)
-	if (ip)
-		*ip = 0;
-	if (sp)
-		*sp = tsk.thread.ksp;
-#else
 #if defined(ARCH_x86_64)
 	if (ip)
 		*ip = tsk.thread.rip;
 	if (sp)
 		*sp = tsk.thread.rsp;
+#else
+#if defined(ARCH_ia64)
+	{
+	struct switch_stack sw;
+	memread((addr_t)tsk.thread.ksp + 16, sizeof(sw), &sw, "switch_stack");
+	if (ip)
+		*ip = sw.b0;
+	if (sp)
+		*sp = sw.ar_bspstore;
+	}
+#if defined(ARCH_ppc) || defined(ARCH_ppc64)
+	if (ip)
+		*ip = 0;
+	if (sp)
+		*sp = tsk.thread.ksp;
 #else
 	/* others */
 	if (ip)
@@ -288,6 +312,7 @@ getinfo_fromtask(addr, ip, sp, stack)
 		*sp = 0;
 #endif
 #endif
+#endif
 #endif
 	if (stack)
 		*stack = addr;
