@@ -77,7 +77,7 @@ print_dentry(addr, sw, subdir, parent)
 	mprintf(FPTR " " FPTR " %2x ", de.d_op, de.d_sb, de.d_flags);
 
 	if (de.d_name.name == ((struct dentry *)addr)->d_iname)
-		mprintstr(de.d_iname, sizeof(de.d_iname));
+		mprintstr((const char *)de.d_iname, sizeof(de.d_iname));
 	else if (de.d_name.name == NULL)
 		mprintf("[null]");
 	else {
@@ -141,12 +141,12 @@ print_file(addr, full)
 	mprintf("\n");
 
 	if (full) {
-		mprintf("\tvfsmnt:     " FPTR "\n", f.f_vfsmnt);
+		mprintf("\tvfsmnt:     " FPTR "  (vfsmount)\n", f.f_vfsmnt);
 		mprintf("\towener.pid: %x\n", f.f_owner.pid);
 		mprintf("\tversion:    %lx\n", f.f_version);
 		mprintf("\tsecurity    " FPTR "\n", f.f_security);
 #ifdef _file_has_f_mapping
-		mprintf("\tmapping:    " FPTR "\n", f.f_mapping);
+		mprintf("\tmapping:    " FPTR "  (address_space)\n", f.f_mapping);
 #endif
 	}
 #ifndef _file_has_f_list
@@ -228,7 +228,11 @@ print_inode(addr, full)
 			inode.i_atime.tv_sec,
 			inode.i_mtime.tv_sec,
 			inode.i_ctime.tv_sec);
+#ifdef _inode_has_i_blksize
 		mprintf("\tblocks:    %ld  (* blksize %ld)\n", inode.i_blocks, inode.i_blksize);
+#else
+		mprintf("\tblocks:    %ld\n", inode.i_blocks);
+#endif
 		mprintf("\tversion:   %ld\n", inode.i_version);
 #ifdef _inode_has_i_mutex
 		mprintf("\tmutex:       ");
@@ -267,7 +271,14 @@ print_inode(addr, full)
 		mprintf("\tdirtied_when: %lx\n", inode.dirtied_when);
 #endif /*_inode_has_dirtied_when*/
 		mprintf("\tgen:       %u\n", inode.i_generation);
+#ifdef _inode_has_i_security
+		mprintf("\tsecurity:  " FPTR "\n", inode.i_security);
+#endif
+#if SUBLEVEL>=19 || defined(_inode_has_i_private)
+		mprintf("\tprivate:   " FPTR "\n", inode.i_private);
+#else
 		mprintf("\tgeneric_ip:" FPTR "\n", inode.u.generic_ip);
+#endif
 		mprintf("\n");
 	}
 	return (addr_t)inode.i_hash.next;
@@ -419,7 +430,7 @@ print_vfsmount(addr, chain)
 	int chain;
 {
 	struct vfsmount m;
-	char path[PATH_MAX];
+	char path[128];
 
 	if (chain) {
 		addr -= OFFSET(struct vfsmount, mnt_hash);
@@ -608,7 +619,11 @@ print_block_device(addr, eflag)
 	mprintf("%4x %5x", bd.bd_openers, bd.bd_block_size);
 	mprintf(" " FPTR " " FPTR, bd.bd_holder, bd.bd_contains);
 	mprintf(" " FPTR " " FPTR, bd.bd_part, bd.bd_disk);
+#ifdef _block_device_has_bd_mutex
+	mprintf(" %5d    ", ATOMIC_READ(bd.bd_mutex.count));
+#else
 	mprintf(" %5d %3d", ATOMIC_READ(bd.bd_sem.count), bd.bd_sem.sleepers);
+#endif
 
 	mprintf(" " FPTR " ", bd.bd_inode);
 	iaddr = (addr_t)bd.bd_inodes.next;
@@ -699,7 +714,11 @@ print_file_lock(addr, full, chain)
 		mprintf("  break_time: %8lx\n", fl.fl_break_time);
 		mprintf("  nfs_fl:     %x  %x  %lx\n",
 			fl.fl_u.nfs_fl.state,
+#ifndef NFS_LCK_GRANTED
+			0,
+#else
 			fl.fl_u.nfs_fl.flags,
+#endif
 #ifdef _file_lock_has_fl_ops
 			fl.fl_u.nfs_fl.owner
 #else
