@@ -15,8 +15,13 @@ extern addr_t print_page();
 void
 prhead_zone()
 {
+#ifndef _zone_has_zone_mem_map
+	mprintf(SPTR" FREEPG "SPTR" STARTPFN PAGES NAME\n",
+		"ADDR", "PGDAT");
+#else
 	mprintf(SPTR" FREEPG "SPTR" "SPTR" STARTPFN PAGES NAME\n",
 		"ADDR", "PGDAT", "MEM_MAP");
+#endif
 }
 
 addr_t
@@ -30,17 +35,20 @@ print_zone(addr, full)
 
 	memread(addr, sizeof(zone), &zone, "zone");
 	if (!full) {
-		mprintf(FPTR " %6lx " FPTR " " FPTR " %8lx %5lx ",
-			addr, zone.free_pages, zone.zone_pgdat,
-			zone.zone_mem_map, zone.zone_start_pfn,
-			zone.present_pages);
+		mprintf(FPTR " %6lx " FPTR " ",
+			addr, zone.free_pages, zone.zone_pgdat);
+#ifdef _zone_has_zone_mem_map
+		mprintf(FPTR " ", zone.zone_mem_map);
+#endif
+		mprintf("%8lx %5lx ",
+			zone.zone_start_pfn, zone.present_pages);
 		memread((addr_t)zone.name, sizeof(buf), &buf, "name");
 		mprintstr(buf, sizeof(buf));
 		mprintf("\n");
 		return 0;
 	}
 
-	mprintf("addr               " FPTR "\n", addr);
+	mprintf("addr               " FPTR "  (%x)\n", addr, sizeof(zone));
 	if (addr == 0) {
 		mprintf("\n");
 		return 0;
@@ -81,10 +89,17 @@ print_zone(addr, full)
 		mprintf("\n");
 	}
 	mprintf("wait_table         " FPTR "\n", zone.wait_table);
+#ifdef _zone_has_wait_table_hash_nr_entries
+	mprintf("wait_table_size    %lx  (2^%lx)\n",
+		zone.wait_table_hash_nr_entries, zone.wait_table_bits);
+#else
 	mprintf("wait_table_size    %lx  (2^%lx)\n",
 		zone.wait_table_size, zone.wait_table_bits);
+#endif
 	mprintf("zone_pgdat         " FPTR "\n", zone.zone_pgdat);
+#ifdef _zone_has_zone_mem_map
 	mprintf("zone_mem_map       " FPTR "\n", zone.zone_mem_map);
+#endif
 	mprintf("zone_start_pfn     %lx\n", zone.zone_start_pfn);
 
 	mprintf("name               \"");
@@ -118,7 +133,7 @@ print_pglist_data(addr)
 	char buf[256];
 	int i, j;
 
-	mprintf("addr               " FPTR "\n", addr);
+	mprintf("addr               " FPTR "  (%x)\n", addr, sizeof(pg));
 	if (addr == 0) {
 		mprintf("\n");
 		return 0;
@@ -147,20 +162,41 @@ print_pglist_data(addr)
 		mprintf("\n");
 	}
 	mprintf("nr_zones           %x\n", pg.nr_zones);
+#if SUBLEVEL<=12 || defined(CONFIG_FLAT_NODE_MEM_MAP)
 	mprintf("node_mem_map       " FPTR "\n", pg.node_mem_map);
+#endif
 	mprintf("bdata              " FPTR "\n", pg.bdata);
 	mprintf("node_start_pfn     %lx\n", pg.node_start_pfn);
 	mprintf("node_present_pages %lx / %lx\n",
 		pg.node_present_pages, pg.node_spanned_pages);
 	mprintf("node_id            %x\n", pg.node_id);
+#ifdef _pglist_data_has_pgdat_next
 	mprintf("pgdat_next         " FPTR "\n", pg.pgdat_next);
+#endif
 #ifdef _pglist_data_has_kswapd
 	mprintf("kswapd             " FPTR "\n", pg.kswapd);
 #endif
 #ifdef _pglist_data_has_kswapd_max_order
 	mprintf("kswapd_max_order   %x\n", pg.kswapd_max_order);
 #endif
+#ifndef _pglist_data_has_pgdat_next
+	return 0; /*XXX*/
+#else
 	return (addr_t)pg.pgdat_next;
+#endif
+}
+
+addr_t
+get_pglist_data_next(addr)
+	addr_t addr;
+{
+	struct pglist_data pg;
+	memread(addr, sizeof(pg), &pg, "pglist_data");
+#ifndef _pglist_data_has_pgdat_next
+	return 0; /*XXX*/
+#else
+	return (addr_t)pg.pgdat_next;
+#endif
 }
 
 void
