@@ -9,6 +9,8 @@
 #include <linux/namespace.h>
 #include <linux/mount.h>
 
+#include "flags_sched.h"
+
 void
 prhead_namespace()
 {
@@ -25,7 +27,15 @@ print_namespace(addr)
 		struct task_struct ts;
 
 		memread(init_task_addr, sizeof(struct task_struct), &ts, "task_struct");
+#if defined(_task_struct_has_noproxy)
+		struct nsproxy nsproxy;
+		memread((addr_t)ts.namespace, sizeof(nsproxy), &nsproxy, "nsproxy");
+		addr = (addr_t)nsproxy.namespace;
+#else
+#if defined(_task_struct_has_namespace)
 		addr = (addr_t)ts.namespace;
+#endif
+#endif
 	}
 
 	memread(addr, sizeof(struct namespace), &ns, "namespace");
