@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -10,6 +10,10 @@
 #include <net/tcp.h>
 #include <net/udp.h>
 
+#ifndef TCP_LHTABLE_SIZE
+#include <net/inet_hashtables.h>	/* after 2.6.14 */
+#endif
+
 //#include "flags_socket.h"
 #include "flags_sock.h"
 
@@ -246,9 +250,40 @@ print_listed_sock(fflag, addr, udp_hash_addr, unix_socket_table_addr)
 	addr_t udp_hash_addr;
 	addr_t unix_socket_table_addr;
 {
-	struct tcp_hashinfo tcp;
 	int i;
 
+#ifndef TCP_LHTABLE_SIZE
+	struct inet_hashinfo tcp;
+
+	memread(addr, sizeof(tcp), &tcp, "tcp_hashinfo");
+
+	mprintf("TCP ESTABLISHED\n");
+	prhead_sock();
+	for (i = 0; i < tcp.ehash_size; i++) {
+		struct inet_ehash_bucket ebucket;
+#ifdef DEBUG
+		mprintf("[" FPTR "]\n", (addr_t)(tcp.ehash + i));
+#endif /*DEBUG*/
+		memread((addr_t)(tcp.ehash + i), sizeof(ebucket), &ebucket, "tcp_ehash_bucket");
+		addr = (addr_t)ebucket.chain.first;	/*XXX*/
+		while (addr) {
+			addr = print_sock(addr, fflag);
+		}
+	}
+
+	mprintf("TCP LISTENING\n");
+	prhead_sock();
+	for (i = 0; i < INET_LHTABLE_SIZE; i++) {
+		addr = (addr_t) tcp.listening_hash[i].first;	/*XXX*/
+		while (addr) {
+			addr = print_sock(addr - OFFSET(struct sock, sk_node), fflag);
+		}
+	}
+
+#else /*TCP_LHTABLE_SIZE*/
+
+	struct tcp_hashinfo tcp;
+
 	memread(addr, sizeof(tcp), &tcp, "tcp_hashinfo");
 
 	mprintf("TCP ESTABLISHED\n");
@@ -273,6 +308,7 @@ print_listed_sock(fflag, addr, udp_hash_addr, unix_socket_table_addr)
 			addr = print_sock(addr - OFFSET(struct sock, sk_node), fflag);
 		}
 	}
+#endif /*TCP_LHTABLE_SIZE*/
 
 	mprintf("UDP\n");
 	prhead_sock();
