@@ -123,11 +123,13 @@ print_nfs_inode(addr, full, iflag)
 #ifdef _nfs_inode_has_data_updates
 		mprintf("data_updates           %x\n",  ATOMIC_READ(ni.data_updates));
 #endif
+#ifdef _nfs_inode_has_cache_access
 		mprintf("cache_access.jiffies   %lx\n", ni.cache_access.jiffies);
 		mprintf("cache_access.cred      "FPTR"\n", ni.cache_access.cred);
 		mprintf("cache_access.mask      %x\n", ni.cache_access.mask);
 #ifdef _nfs_inode_has_err
 		mprintf("cache_access.err       %x\n", ni.cache_access.err);
+#endif
 #endif
 		mprintf("cookieverf             %x  %x\n",
 					ni.cookieverf[0], ni.cookieverf[1]);
@@ -161,18 +163,29 @@ print_nfs_server(dummy, addr, full)
 
 	memread(addr, sizeof(server), &server, "nfs_server");
 	mprintf(FPTR " ", addr);
-	mprintf(FPTR " " FPTR " ", server.client, server.rpc_ops);
+	mprintf(FPTR " ", server.client);
+#ifdef _nfs_server_has_nfs_client
+	mprintf(FPTR " ", server.nfs_client);
+#else
+#ifdef _nfs_server_has_rpc_ops
+	mprintf(FPTR " ", server.rpc_ops);
+#endif
+#endif
 	mprintf("%5x %5x %5x %5x ",
 		server.rsize, server.wsize,
 		server.dtsize, server.bsize);
 
 	mprintf("%3x ", server.flags);
+#ifdef _nfs_server_has_hostname
 	memread((addr_t)server.hostname, sizeof(buf), buf, "nfs_server.hostname");
 	mprintstr(buf, sizeof(buf));
+#endif
 	mprintf("\n");
 
 	if (full) {
+#ifdef _nfs_server_has_fh
 		mprint_nfs_fh(&server.fh);
+#endif
 		mprintf("    REG %d-%d   DIR %d-%d\n",
 			server.acregmin, server.acregmax,
 			server.acdirmin, server.acdirmax);
