@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2005 ASANO Masahiro
+ * Copyright (C) 2000-2006 ASANO Masahiro
  */
 
 #include "def.h"
@@ -38,6 +38,23 @@ print_files_struct(addr)
 	memread(addr, sizeof(files), &files, "files_struct");
 	mprintf("%3x ", ATOMIC_READ(files.count));
 #ifdef _files_struct_has_fdtab
+#ifdef _files_struct_has_next_fd
+	struct fdtable fdtab;
+	if ((addr_t)files.fdt == addr + OFFSET(struct files_struct, fdtab))
+		m_memcpy(&fdtab, &files.fdtab, sizeof(fdtab));
+	else
+		memread((addr_t)files.fdt, sizeof(fdtab), &fdtab, "fdtable");
+	mprintf("%5d %5d %5d", fdtab.max_fds, fdtab.max_fdset, files.next_fd);
+	mprintf(" " FPTR " " FPTR " " FPTR "\n", fdtab.fd, fdtab.close_on_exec, fdtab.open_fds);
+	if ((addr_t)fdtab.fd == addr + OFFSET(struct files_struct, fd_array))
+		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
+	else
+		memread((addr_t)fdtab.fd, sizeof(fds), fds, "file");
+	if ((addr_t)fdtab.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
+		m_memcpy(&cfd, &files.close_on_exec_init, sizeof(files.close_on_exec_init));
+	else
+		memread((addr_t)fdtab.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
+#else /*_files_struct_has_next_fd*/
 	struct fdtable fdtab;
 	if ((addr_t)files.fdt == addr + OFFSET(struct files_struct, fdtab))
 		m_memcpy(&fdtab, &files.fdtab, sizeof(fdtab));
@@ -53,6 +70,7 @@ print_files_struct(addr)
 		cfd = files.close_on_exec_init;
 	else
 		memread((addr_t)fdtab.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
+#endif /*_files_struct_has_next_fd*/
 #else /*_files_struct_has_fdtab*/
 	mprintf("%5d %5d %5d", files.max_fds, files.max_fdset, files.next_fd);
 	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fd, files.close_on_exec, files.open_fds);
@@ -110,7 +128,7 @@ prhead_task(sw)
 	case 5:
 		p = "SIGHAND";	break;
 	case 6:
-		p = "NAMESPAC";	break;
+		p = "CPUSET";	break;
 	default:
 		sw = saved_sw_task;
 		goto retry;
@@ -175,7 +193,7 @@ print_task(addr, full)
 	case 5:
 		mprintf(FPTR, ts.sighand);	break;
 	case 6:
-		mprintf(FPTR, ts.namespace);	break;
+		mprintf(FPTR, ts.cpuset);	break;
 	}
 	mprintf(" %-16s", ts.comm);
 	mprintbit(tsflags, ts.flags);
@@ -188,11 +206,15 @@ print_task(addr, full)
 	print_files_struct(ts.files);
 
 	mprintf("\tthread_info:" FPTR "\n", ts.thread_info);
-	mprintf("\tlock_depth: %d\n",       ts.lock_depth);
-	mprintf("\tprio:       %x\n",       ts.prio);
-	mprintf("\tmm:         " FPTR "  (mm_struct)\n",   ts.mm);
-	mprintf("\tbinfmt:     " FPTR "  (binfmt)\n",      ts.binfmt);
+	mprintf("\tlock_depth: %d\n", ts.lock_depth);
+	mprintf("\tprio:       %x\n", ts.prio);
+	mprintf("\t&run_list:  " FPTR "  (list_head)\n", addr + OFFSET(struct task_struct, run_list));
+	mprintf("\tarray:      " FPTR "\n", ts.array);
+	mprintf("\tmm:         " FPTR "  (mm_struct)\n", ts.mm);
+	mprintf("\tbinfmt:     " FPTR "  (binfmt)\n", ts.binfmt);
 	mprintf("\tparent:     " FPTR "  (task_struct)\n", ts.parent);
+	mprintf("\t&children:  " FPTR "  (list_head)\n", addr + OFFSET(struct task_struct, children));
+	mprintf("\t&sibling:   " FPTR "  (list_head)\n", addr + OFFSET(struct task_struct, sibling));
 #ifdef _task_struct_has_cutime
 	mprintf("\ttimes:      %lx %lx - %lx %lx\n",
 		ts.utime, ts.stime, ts.cutime, ts.cstime);
@@ -203,10 +225,15 @@ print_task(addr, full)
 	mprintf("\tcap:        %x\n", ts.cap_effective);
 	mprintf("\tuser:       " FPTR "  (user_struct)\n", ts.user);
 #ifdef _task_struct_has_tty
-	mprintf("\ttty:        " FPTR "  (tty_struct)\n",  ts.tty);
+	mprintf("\ttty:        " FPTR "  (tty_struct)\n", ts.tty);
+#endif
+	mprintf("\tfs:         " FPTR "  (fs_struct)\n", ts.fs);
+#ifdef _task_struct_has_nsproxy
+	mprintf("\tnsproxy:    " FPTR "\n", ts.nsproxy);
+#endif
+#ifdef _task_struct_has_namespace
+	mprintf("\tnamespace:  " FPTR "  (namespace)\n", ts.namespace);
 #endif
-	mprintf("\tfs:         " FPTR "  (fs_struct)\n",   ts.fs);
-	mprintf("\tnamespace:  " FPTR "  (namespace)\n",   ts.namespace);
 	mprintf("\tthread:     %lx\n", addr + OFFSET(struct task_struct, thread));
 	mprintf("\tsignal:     " FPTR "  (signal_struct)\n", ts.signal);
 	mprintf("\tsighand:    " FPTR "  (sighand_struct)\n", ts.sighand);
@@ -219,6 +246,20 @@ print_task(addr, full)
 #if defined(ARCH_ia64)
 	mprintf("\tksp:%lx  flags:%lx\n", ts.thread.ksp, ts.thread.flags);
 	mprintf("\tmap_base:%lx  task_size:%lx\n", ts.thread.map_base, ts.thread.task_size);
+	if (full >= 2) {
+		struct switch_stack sw;
+		memread((addr_t)ts.thread.ksp + 16, sizeof(sw), &sw,
+			"switch_stack");
+		mprintf("\tb0:%lx    b1:%lx\n", sw.b0, sw.b1);
+		mprintf("\tpfs:%lx   (rrb.pr:%d, rrb.fr:%d, rrb.gr:%d, sor:%d, sol:%d, sof:%d)\n",
+			sw.ar_pfs, (int)(sw.ar_pfs>>32),
+			(int)(sw.ar_pfs>>25) & 127,
+			(int)(sw.ar_pfs>>18) & 127,
+			(int)(sw.ar_pfs>>14) & 15,
+			(int)(sw.ar_pfs>>7) & 127,
+			(int)sw.ar_pfs & 127);
+		mprintf("\tbspstore:%lx pr:%lx\n", sw.ar_bspstore);
+	}
 #endif /*ARCH_ia64*/
 #if defined(ARCH_ppc) || defined(ARCH_ppc64)
 	mprintf("\tksp:%lx\n", ts.thread.ksp);
@@ -244,17 +285,27 @@ getinfo_fromtask(addr, ip, sp, stack)
 	if (sp)
 		*sp = tsk.thread.esp;
 #else
-#if defined(ARCH_ia64) || defined(ARCH_ppc) || defined(ARCH_ppc64)
-	if (ip)
-		*ip = 0;
-	if (sp)
-		*sp = tsk.thread.ksp;
-#else
 #if defined(ARCH_x86_64)
 	if (ip)
 		*ip = 0;
 	if (sp)
 		*sp = tsk.thread.rsp;
+#else
+#if defined(ARCH_ia64)
+	{
+	struct switch_stack sw;
+	memread((addr_t)tsk.thread.ksp + 16, sizeof(sw), &sw, "switch_stack");
+	if (ip)
+		*ip = sw.b0;
+	if (sp)
+		*sp = sw.ar_bspstore;
+	}
+#else
+#if defined(ARCH_ppc) || defined(ARCH_ppc64)
+	if (ip)
+		*ip = 0;
+	if (sp)
+		*sp = tsk.thread.ksp;
 #else
 	/* others */
 	if (ip)
@@ -263,6 +314,7 @@ getinfo_fromtask(addr, ip, sp, stack)
 		*sp = 0;
 #endif
 #endif
+#endif
 #endif
 	if (stack)
 		*stack = (addr_t)tsk.thread_info;
@@ -311,10 +363,25 @@ print_mm_struct(addr, vflag)
 		mprintf(FPTR " " FPTR " %8lx\n",
 			mm.start_brk,  mm.brk, mm.total_vm);
 	} else {
-		mprintf("addr:       " FPTR "\n", addr);
-		mprintf("mmap:       " FPTR "\n", mm.mmap);
-		mprintf("mmap_cache: " FPTR "\n", mm.mmap_cache);
-		mprintf("pgd:        " FPTR "\n", mm.pgd);
+#ifdef _mm_struct_has_get_unmapped_area
+		const char *s;
+#endif
+		mprintf("addr:       " FPTR "  (%x)\n", addr, sizeof(mm));
+		mprintf("mmap:       " FPTR "  (vm_area_struct)\n", mm.mmap);
+		mprintf("mmap_cache: " FPTR "  (vm_area_struct)\n", mm.mmap_cache);
+#ifdef _mm_struct_has_get_unmapped_area
+		mprintf("get_unmapped_area " FPTR, mm.get_unmapped_area);
+		mprintf("  %s\n", (s = getsymstr_func((addr_t)mm.get_unmapped_area))? s: "-");
+		mprintf("unmap_area        " FPTR, mm.unmap_area);
+		mprintf("  %s\n", (s = getsymstr_func((addr_t)mm.unmap_area))? s: "-");
+#endif
+#ifdef _mm_struct_has_mmap_base
+		mprintf("mmap_base   %lx\n", mm.mmap_base);
+#endif
+#ifdef _mm_struct_has_free_area_cache
+		mprintf("free_area_cache %lx\n", mm.free_area_cache);
+#endif
+		mprintf("pgd:        " FPTR "  (pgd)\n", mm.pgd);
 		mprintf("mm_users:   %x\n", ATOMIC_READ(mm.mm_users));
 		mprintf("mm_count:   %x\n", ATOMIC_READ(mm.mm_count));
 		mprintf("map_count:  %x\n", mm.map_count);
@@ -426,11 +493,11 @@ print_sighand_struct(addr)
 		mprintf("%2d: ", i + 1);
 		switch ((long)sa->sa_handler) {
 		case (long)SIG_DFL:
-			mprintf(SPTR, "DFL");   break;
+			mprintf(SPTR, "DFL");	break;
 		case (long)SIG_IGN:
-			mprintf(SPTR, "IGNORE");        break;
+			mprintf(SPTR, "IGNORE");	break;
 		case (long)SIG_ERR:
-			mprintf(SPTR, "ERR");   break;
+			mprintf(SPTR, "ERR");	break;
 		default:
 			mprintf(FPTR, sa->sa_handler);
 		}
