@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -13,7 +13,7 @@
 void
 prhead_swap_info()
 {
-	mprintf(SPTR " " SPTR " " SPTR " NRX " SPTR " PRIO PAGES      MAX FLAGS\n",
+	mprintf(SPTR " " SPTR " " SPTR " " SPTR " PRIO PAGES      MAX FLAGS\n",
 		"ADDR", "FILE", "BDEV", "MAP");
 }
 
@@ -47,8 +47,8 @@ print_swap_info(n, full)
 	}
 	memread(addr, sizeof(si), &si, "swap_info");
 
-	mprintf(FPTR " " FPTR " %3x " FPTR " ",
-		si.swap_file, si.bdev, si.nr_extents, si.swap_map);
+	mprintf(FPTR " " FPTR " " FPTR " ",
+		si.swap_file, si.bdev, si.swap_map);
 	mprintf("%4d %5x %8lx", si.prio, si.pages, si.max);
 	mprintf("%s%s\n", (si.flags & SWP_USED)? " used": "",
 			  (si.flags & SWP_WRITEOK) == SWP_WRITEOK? " writeok": "");
