@@ -12,7 +12,7 @@
 void
 prhead_tty_struct()
 {
-	mprintf(SPTR" "SPTR" IDX "SPTR"  PGRP  SESS FLG CNT SHFPLW "SPTR" NAME\n",
+	mprintf(SPTR" "SPTR" IDX "SPTR"  PGRP  SESS  FLAG CNT SHFPLW "SPTR" NAME\n",
 		"ADDR", "DRIVER", "TERMIOS", "LINK");
 }
 
@@ -32,7 +32,7 @@ print_tty_struct(addr, full)
 
 	mprintf(FPTR " %3x " FPTR " ", tty.driver, tty.index, tty.termios);
 	mprintf("%5d %5d ", tty.pgrp, tty.session);
-	mprintf("%3lx %3x ", tty.flags, tty.count);
+	mprintf("%5lx %3x ", tty.flags, tty.count);
 	mprintf("%c%c%c%c%c%c ",
 		tty.stopped     ? 's': '-',
 		tty.hw_stopped  ? 'h': '-',
