@@ -184,7 +184,9 @@ print_usb_bus(addr, list_offset, full)
 	mprintf(FPTR " ", ub.controller);
 	mprintf("%3x ", ub.busnum);
 	mprintf("%3x ", ub.devnum_next);
+#ifdef _usb_bus_has_op
 	mprintf(FPTR " " FPTR " " FPTR " ", ub.op, ub.root_hub, ub.hcpriv);
+#endif
 	mprintf("%3x %3x %3x ", ub.bandwidth_allocated,
 		ub.bandwidth_int_reqs, ub.bandwidth_isoc_reqs);
 	for (i = 0; i < LENGTHOF(ub.devmap.devicemap); i++) {
@@ -198,9 +200,14 @@ print_usb_bus(addr, list_offset, full)
 #ifdef _usb_bus_has_usbdevfs_dentry
 		mprintf("  usbdevfs_dentry: " FPTR "\n", ub.usbdevfs_dentry);
 #endif
+#ifdef _usb_bus_has_release
 		mprintf("  release:         " FPTR "  ", ub.release);
 		p = getsymstr_func((addr_t)ub.release);
 		mprintf("%s\n", p? p: "-");
+#endif
+#ifdef _usb_bus_has_class_dev
+		mprintf("  class_dev:       " FPTR "\n", ub.class_dev);
+#endif
 	}
 
 	return (addr_t)ub.bus_list.next;
