@@ -14,7 +14,7 @@ extern addr_t print_sighand_struct();
 PRIVATE addr_t signal_struct();
 const commandtable_t command_signal_struct =
 	{"signal_struct", signal_struct, "address", "print signal_struct table"};
-extern void prhead_signal_strut();
+extern void prhead_signal_struct();
 extern addr_t print_signal_struct();
 
 PRIVATE addr_t
