@@ -3,6 +3,7 @@
  */
 
 #include <unistd.h>
+#include <stdlib.h>
 #include "crash.h"
 #include "mpercpu.h"
 
@@ -38,7 +39,7 @@ timer_vec()
 			if (cpu < 0)
 				THROW(usage);
 			if (cpu >= LENGTHOF(__per_cpu_offset))
-				THROW(usage);
+				THROW("cpu out of range");
 			break;
 		default:
 			THROW(usage);
