@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -25,5 +25,5 @@ translate_addr(addr, count, errmsg)
 		THROWF("Error: V-P translation error(high): %lx", addr);
 	}
 	/* global address */
-	return addr - kmem_low;
+	return _PA(addr);
 }
