@@ -48,10 +48,10 @@ trace()
 #define	INTHESTACK(x) ((x) >= stacktop && (x) + sizeof(addr_t) <= stacktop + STACKSIZE)
 	if (!INTHESTACK(esp))
 		return 0;
-	esp = *(unsigned int *)&stack[esp - stacktop] + sizeof(addr_t);
+	esp = *(addr_t *)&stack[esp - stacktop] + sizeof(addr_t);
 	if (!INTHESTACK(esp))
 		return 0;
-	retad = *(unsigned int *)&stack[esp - stacktop];
+	retad = *(addr_t *)&stack[esp - stacktop];
 	sym = searchsym_byaddr(retad);
 	argsize = 0;
 
@@ -197,18 +197,18 @@ trace()
 			mprintf(")\n");
 			continue;
 		}
-		retad = *(unsigned int *)&stack[esp - stacktop];
+		retad = *(addr_t *)&stack[esp - stacktop];
 		if (retad < kmem_low ||
 		    (sym = searchsym_byaddr(retad)) == NULL ||
 		    retad - sym->addr > 0x10000 ||
 		    (sym->addr <= retad && sym->addr + 1 >= retad)) {
 			/* maybe stack analyze fail, do RECOVERY code */
 			/* save the pointers */
-			int esp_save = esp, retad_save = retad;
+			addr_t esp_save = esp, retad_save = retad;
 			/* search the next function from stack */
 			sym = NULL;
 			while (esp++, INTHESTACK(esp)) {
-				retad = *(unsigned int *)&stack[esp - stacktop];
+				retad = *(addr_t *)&stack[esp - stacktop];
 				if (retad < kmem_low)
 					continue;
 				sym = searchsym_byaddr(retad);
@@ -233,11 +233,11 @@ trace()
 		    (strcmp(sym->name, "stext_lock") == 0 || strncmp(sym->name, "_text_lock_", 11) == 0 || strncmp(sym->name, ".text.lock.", 11) == 0)) {
 			mprintf(")\n[%8lx] %8lx  [%s]\n", esp, retad, getsymstr(retad));
 			if (funchead[0] == 0xe9)
-				retad += *(unsigned int *)&funchead[1] + 5;
+				retad += *(addr_t *)&funchead[1] + 5;
 			else if (funchead[1] == 0xe9)
-				retad += *(unsigned int *)&funchead[2] + 6;
+				retad += *(addr_t *)&funchead[2] + 6;
 			else
-				retad += *(unsigned int *)&funchead[3] + 7;
+				retad += *(addr_t *)&funchead[3] + 7;
 			sym = searchsym_byaddr(retad);
 			continue;
 		}
@@ -302,18 +302,18 @@ trace()
 			}
 		}
 		if (argsize) {
-			for (i = 0; i < argsize; i += sizeof(int)) {
+			for (i = 0; i < argsize; i += sizeof(addr_t)) {
 				if (i) mprintf(",");
-				if (!INTHESTACK(esp + sizeof(int) + i))
+				if (!INTHESTACK(esp + sizeof(addr_t) + i))
 					break;
-				mprintf("%x", *(int*)&stack[esp - stacktop + sizeof(int) + i]);
+				mprintf("%lx", *(addr_t*)&stack[esp - stacktop + sizeof(addr_t) + i]);
 			}
 		} else {
-			for (i = 0; i < 4 * sizeof(int); i += sizeof(int)) {
+			for (i = 0; i < 4 * sizeof(addr_t); i += sizeof(addr_t)) {
 				if (i) mprintf(",");
-				if (!INTHESTACK(esp + sizeof(int) + i))
+				if (!INTHESTACK(esp + sizeof(addr_t) + i))
 					break;
-				mprintf("%x", *(int*)&stack[esp - stacktop + sizeof(int) + i]);
+				mprintf("%lx", *(addr_t*)&stack[esp - stacktop + sizeof(addr_t) + i]);
 			}
 		}
 		mprintf(")\n");
