@@ -4,7 +4,7 @@ extern struct commandtable command_dis, command_trace, command_pte, command_pgd,
 	command_vtop;
 
 const struct commandtable *commandtable_arch[] = {
-/*	&command_dis,*/
+	&command_dis,
 	&command_pgd,
 	&command_pte,
 	&command_trace,
