@@ -9,7 +9,6 @@ PRIVATE addr_t module();
 const commandtable_t command_module =
 	{"module", module, "[address]", "print module table"};
 
-addr_t module_list_addr;
 extern addr_t print_module();
 extern addr_t getmsyms();
 
@@ -41,17 +40,27 @@ module()
 	} else {
 #if LINUXVER>=25
 		static addr_t modules_addr;
+		struct list_head modules;	
+		extern int module_offset_list;
+
 		GETADDR(modules);
-		module_list_addr = modules_addr;
+		memread(modules_addr, sizeof(modules), &modules, "modules");
+		addr = (addr_t)modules.next;
+		if (!full) prhead_module();
+		while (addr && addr != modules_addr) {
+			if (full) prhead_module();
+			addr = print_module(addr - module_offset_list, full);
+		}
 #else
+		static addr_t module_list_addr;
 		GETADDR(module_list);
-#endif
 		memread(module_list_addr, sizeof(addr), &addr, "module_list");
 		if (!full) prhead_module();
-		while (addr && addr != module_list_addr) {
+		while (addr) {
 			if (full) prhead_module();
 			addr = print_module(addr, full);
 		}
+#endif
 	}
 	return addr;
 }
@@ -64,10 +73,22 @@ get_module_symbol(addr)
 	addr_t addr;
 {
 	TRY {
+#if LINUXVER>=25
+		struct list_head modules;	
+		addr_t tmp;
+		extern int module_offset_list;
+
+		memread(addr, sizeof(modules), &modules, "modules");
+		tmp = (addr_t)modules.next;
+		while (tmp && addr != tmp) {
+			tmp = getmsyms(tmp - module_offset_list);
+		}
+#else
 		memread(addr, sizeof(addr), &addr, "module_list");
-		while (addr && addr != module_list_addr) {
+		while (addr) {
 			addr = getmsyms(addr);
 		}
+#endif /*LINUXVER*/
 	} CATCH {
 		fprintf(stderr, "%s\n", except_message);
 	}
