@@ -53,19 +53,21 @@ print_xfs_perag(addr, flags)
 	int i;
 
 	memread(addr, sizeof(pag), &pag, "xfs_perag_t");
-	mprintf("addr          " FPTR "  (%x)\n", addr, sizeof(pag));
-	mprintf("agf_init      %x\n", pag.pagf_init);
-	mprintf("agi_init      %x\n", pag.pagi_init);
-	mprintf("agf_metadata  %x\n", pag.pagf_metadata);
-	mprintf("agf_levels   ");
+	mprintf("addr           " FPTR "  (%x)\n", addr, sizeof(pag));
+	mprintf("pagf_init      %x\n", pag.pagf_init);
+	mprintf("pagi_init      %x\n", pag.pagi_init);
+	mprintf("pagf_metadata  %x\n", pag.pagf_metadata);
+	mprintf("pagi_inodeok   %x\n", pag.pagi_inodeok);
+	mprintf("pagf_levels   ");
 	for (i = 0; i < XFS_BTNUM_AGF; i++) {
 		mprintf(" %2x", pag.pagf_levels[i]);
 	}
 	mprintf("\n");
-	mprintf("agf_freeblks  %x\n", pag.pagf_freeblks);
-	mprintf("agf_longest   %x\n", pag.pagf_longest);
-	mprintf("agi_freecount %x\n", pag.pagi_freecount);
-	mprintf("agb_list      " FPTR "\n", pag.pagb_list);
+	mprintf("pagf_flcount   %x\n", pag.pagf_flcount);
+	mprintf("pagf_freeblks  %x\n", pag.pagf_freeblks);
+	mprintf("pagf_longest   %x\n", pag.pagf_longest);
+	mprintf("pagi_freecount %x\n", pag.pagi_freecount);
+	mprintf("pagb_list      " FPTR "\n", pag.pagb_list);
 
 #ifdef XFS_PAGB_NUM_SLOTS
 	if (pag.pagf_init && pag.pagb_list) {
