@@ -9,10 +9,14 @@
 #include <xfs_log.h>
 #include <xfs_inum.h>
 #include <xfs_trans.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir.h>
+#endif
 #include <xfs_dir2.h>
 #include <xfs_bmap_btree.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir_sf.h>
+#endif
 #include <xfs_dir2_sf.h>
 #include <xfs_attr_sf.h>
 #include <xfs_dinode.h>
