@@ -9,10 +9,14 @@
 #include <xfs_log.h>
 #include <xfs_inum.h>
 #include <xfs_trans.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir.h>
+#endif
 #include <xfs_dir2.h>
 #include <xfs_bmap_btree.h>
+#ifdef HAVE_XFS_DIR1
 #include <xfs_dir_sf.h>
+#endif
 #include <xfs_dir2_sf.h>
 #include <xfs_attr_sf.h>
 #include <xfs_dinode.h>
@@ -264,8 +268,10 @@ print_xfs_trans(addr, aflag)
 	mprintf("logcb.func:   " FPTR " ( " FPTR " )\n",
 					trans.t_logcb.cb_func,
 					trans.t_logcb.cb_arg);
+#if 0
 	mprintf("forw/back:    " FPTR " " FPTR "\n",
 					trans.t_forw, trans.t_back);
+#endif
 	mprintf("type:         %x  %s\n", trans.t_type, xfs_transaction_type(trans.t_type));
 	mprintf("log_res:      %x\n", trans.t_log_res);
 	mprintf("log_count:    %x\n", trans.t_log_count);
@@ -297,12 +303,14 @@ print_xfs_trans(addr, aflag)
 		mprintf("frextents_delta:     %lx\n", trans.t_frextents_delta);
 	if (trans.t_res_frextents_delta)
 		mprintf("res_frextents_delta: %lx\n", trans.t_res_frextents_delta);
+#if 0
 	if (trans.t_ag_freeblks_delta)
 		mprintf("ag_freeblks_delta    %lx\n", trans.t_ag_freeblks_delta);
 	if (trans.t_ag_flist_delta)
 		mprintf("ag_flist_delta:      %lx\n", trans.t_ag_flist_delta);
 	if (trans.t_ag_btree_delta)
 		mprintf("ag_btree_delta:      %lx\n", trans.t_ag_btree_delta);
+#endif
 	if (trans.t_dblocks_delta)
 		mprintf("dblocks_delta:       %lx\n", trans.t_dblocks_delta);
 	if (trans.t_agcount_delta)
