@@ -13,10 +13,10 @@ prhead_xfs_vfs()
 {
 #if 1
 	/* new style */
-	mprintf(SPTR" "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
+	mprintf(SPTR" FLAG     FSID "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
 #else
 	/* old fashion */
-	mprintf(SPTR" BUSY BSIZE "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
+	mprintf(SPTR" FLAG     FSID BUSY BSIZE "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
 #endif
 }
 
@@ -24,13 +24,17 @@ addr_t
 print_xfs_vfs(addr)
 	addr_t addr;
 {
+#if PATCHLEVEL==6 && SUBLEVEL>=19
+	bhv_vfs_t vfs;
+#else
 	vfs_t vfs;
+#endif
 
 	memread(addr, sizeof(vfs), &vfs, "vfs_t");
 	mprintf(FPTR " ", addr);
 
-#if 1
-#else
+	mprintf("%4x %8x ", vfs.vfs_flag, vfs.vfs_fsid);
+#if 0
 	/* old fashion */
 	mprintf("%4x %5x ", vfs.vfs_busycnt, vfs.vfs_bsize);
 #endif
