@@ -82,13 +82,16 @@ xlog_in_core()
 {
 	int i, c;
 	addr_t addr = 0, saddr;
-	int aflag = 0;
+	int aflag = 0, fflag = 0;
 
-	while ((c = getopt(argcnt, args, "a")) != EOF) {
+	while ((c = getopt(argcnt, args, "af")) != EOF) {
 		switch (c) {
 		case 'a':
 			aflag = 1;
 			break;
+		case 'f':
+			fflag = 1;
+			break;
 		default:
 			THROW(usage);
 		}
@@ -99,7 +102,7 @@ xlog_in_core()
 		for (i = optind; i < argcnt; i++) {
 			addr = saddr = getvalue(args[i]);
 			do {
-				addr = print_xlog_in_core(addr);
+				addr = print_xlog_in_core(addr, fflag);
 			} while (aflag && addr && saddr != addr);
 		}
 	} else {
